@@ -1,20 +1,22 @@
 """
 Type annotations for kinesisanalyticsv2 service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/type_defs.html)
 
 Usage::
 
     ```python
-    from mypy_boto3_kinesisanalyticsv2.type_defs import AddApplicationCloudWatchLoggingOptionResponseTypeDef
+    from mypy_boto3_kinesisanalyticsv2.type_defs import AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef
 
-    data: AddApplicationCloudWatchLoggingOptionResponseTypeDef = {...}
+    data: AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     ApplicationModeType,
     ApplicationRestoreTypeType,
@@ -28,6 +30,7 @@ from .literals import (
     RecordFormatTypeType,
     RuntimeEnvironmentType,
     SnapshotStatusType,
+    UrlTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -37,11 +40,17 @@ else:
 
 
 __all__ = (
+    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
     "AddApplicationCloudWatchLoggingOptionResponseTypeDef",
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
     "AddApplicationInputProcessingConfigurationResponseTypeDef",
+    "AddApplicationInputRequestRequestTypeDef",
     "AddApplicationInputResponseTypeDef",
+    "AddApplicationOutputRequestRequestTypeDef",
     "AddApplicationOutputResponseTypeDef",
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
     "AddApplicationReferenceDataSourceResponseTypeDef",
+    "AddApplicationVpcConfigurationRequestRequestTypeDef",
     "AddApplicationVpcConfigurationResponseTypeDef",
     "ApplicationCodeConfigurationDescriptionTypeDef",
     "ApplicationCodeConfigurationTypeDef",
@@ -71,22 +80,36 @@ __all__ = (
     "CodeContentDescriptionTypeDef",
     "CodeContentTypeDef",
     "CodeContentUpdateTypeDef",
+    "CreateApplicationPresignedUrlRequestRequestTypeDef",
     "CreateApplicationPresignedUrlResponseTypeDef",
+    "CreateApplicationRequestRequestTypeDef",
     "CreateApplicationResponseTypeDef",
+    "CreateApplicationSnapshotRequestRequestTypeDef",
     "CustomArtifactConfigurationDescriptionTypeDef",
     "CustomArtifactConfigurationTypeDef",
+    "DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
     "DeleteApplicationCloudWatchLoggingOptionResponseTypeDef",
+    "DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef",
     "DeleteApplicationInputProcessingConfigurationResponseTypeDef",
+    "DeleteApplicationOutputRequestRequestTypeDef",
     "DeleteApplicationOutputResponseTypeDef",
+    "DeleteApplicationReferenceDataSourceRequestRequestTypeDef",
     "DeleteApplicationReferenceDataSourceResponseTypeDef",
+    "DeleteApplicationRequestRequestTypeDef",
+    "DeleteApplicationSnapshotRequestRequestTypeDef",
+    "DeleteApplicationVpcConfigurationRequestRequestTypeDef",
     "DeleteApplicationVpcConfigurationResponseTypeDef",
     "DeployAsApplicationConfigurationDescriptionTypeDef",
     "DeployAsApplicationConfigurationTypeDef",
     "DeployAsApplicationConfigurationUpdateTypeDef",
+    "DescribeApplicationRequestRequestTypeDef",
     "DescribeApplicationResponseTypeDef",
+    "DescribeApplicationSnapshotRequestRequestTypeDef",
     "DescribeApplicationSnapshotResponseTypeDef",
+    "DescribeApplicationVersionRequestRequestTypeDef",
     "DescribeApplicationVersionResponseTypeDef",
     "DestinationSchemaTypeDef",
+    "DiscoverInputSchemaRequestRequestTypeDef",
     "DiscoverInputSchemaResponseTypeDef",
     "EnvironmentPropertiesTypeDef",
     "EnvironmentPropertyDescriptionsTypeDef",
@@ -127,9 +150,13 @@ __all__ = (
     "LambdaOutputDescriptionTypeDef",
     "LambdaOutputTypeDef",
     "LambdaOutputUpdateTypeDef",
+    "ListApplicationSnapshotsRequestRequestTypeDef",
     "ListApplicationSnapshotsResponseTypeDef",
+    "ListApplicationVersionsRequestRequestTypeDef",
     "ListApplicationVersionsResponseTypeDef",
+    "ListApplicationsRequestRequestTypeDef",
     "ListApplicationsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "MappingParametersTypeDef",
     "MavenReferenceTypeDef",
@@ -150,6 +177,7 @@ __all__ = (
     "ReferenceDataSourceTypeDef",
     "ReferenceDataSourceUpdateTypeDef",
     "ResponseMetadataTypeDef",
+    "RollbackApplicationRequestRequestTypeDef",
     "RollbackApplicationResponseTypeDef",
     "RunConfigurationDescriptionTypeDef",
     "RunConfigurationTypeDef",
@@ -170,8 +198,14 @@ __all__ = (
     "SqlApplicationConfigurationTypeDef",
     "SqlApplicationConfigurationUpdateTypeDef",
     "SqlRunConfigurationTypeDef",
+    "StartApplicationRequestRequestTypeDef",
+    "StopApplicationRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateApplicationMaintenanceConfigurationRequestRequestTypeDef",
     "UpdateApplicationMaintenanceConfigurationResponseTypeDef",
+    "UpdateApplicationRequestRequestTypeDef",
     "UpdateApplicationResponseTypeDef",
     "VpcConfigurationDescriptionTypeDef",
     "VpcConfigurationTypeDef",
@@ -184,14 +218,48 @@ __all__ = (
     "ZeppelinMonitoringConfigurationUpdateTypeDef",
 )
 
+_RequiredAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "_RequiredAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CloudWatchLoggingOption": "CloudWatchLoggingOptionTypeDef",
+    },
+)
+_OptionalAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "_OptionalAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    {
+        "CurrentApplicationVersionId": int,
+        "ConditionalToken": str,
+    },
+    total=False,
+)
+
+
+class AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef(
+    _RequiredAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef,
+    _OptionalAddApplicationCloudWatchLoggingOptionRequestRequestTypeDef,
+):
+    pass
+
+
 AddApplicationCloudWatchLoggingOptionResponseTypeDef = TypedDict(
     "AddApplicationCloudWatchLoggingOptionResponseTypeDef",
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+AddApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "InputId": str,
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
     },
-    total=False,
 )
 
 AddApplicationInputProcessingConfigurationResponseTypeDef = TypedDict(
@@ -201,8 +269,17 @@ AddApplicationInputProcessingConfigurationResponseTypeDef = TypedDict(
         "ApplicationVersionId": int,
         "InputId": str,
         "InputProcessingConfigurationDescription": "InputProcessingConfigurationDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+AddApplicationInputRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Input": "InputTypeDef",
     },
-    total=False,
 )
 
 AddApplicationInputResponseTypeDef = TypedDict(
@@ -211,8 +288,17 @@ AddApplicationInputResponseTypeDef = TypedDict(
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "InputDescriptions": List["InputDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+AddApplicationOutputRequestRequestTypeDef = TypedDict(
+    "AddApplicationOutputRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Output": "OutputTypeDef",
     },
-    total=False,
 )
 
 AddApplicationOutputResponseTypeDef = TypedDict(
@@ -221,8 +307,17 @@ AddApplicationOutputResponseTypeDef = TypedDict(
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "OutputDescriptions": List["OutputDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ReferenceDataSource": "ReferenceDataSourceTypeDef",
     },
-    total=False,
 )
 
 AddApplicationReferenceDataSourceResponseTypeDef = TypedDict(
@@ -231,18 +326,42 @@ AddApplicationReferenceDataSourceResponseTypeDef = TypedDict(
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "ReferenceDataSourceDescriptions": List["ReferenceDataSourceDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredAddApplicationVpcConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredAddApplicationVpcConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "VpcConfiguration": "VpcConfigurationTypeDef",
+    },
+)
+_OptionalAddApplicationVpcConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalAddApplicationVpcConfigurationRequestRequestTypeDef",
+    {
+        "CurrentApplicationVersionId": int,
+        "ConditionalToken": str,
     },
     total=False,
 )
 
+
+class AddApplicationVpcConfigurationRequestRequestTypeDef(
+    _RequiredAddApplicationVpcConfigurationRequestRequestTypeDef,
+    _OptionalAddApplicationVpcConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 AddApplicationVpcConfigurationResponseTypeDef = TypedDict(
     "AddApplicationVpcConfigurationResponseTypeDef",
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "VpcConfigurationDescription": "VpcConfigurationDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredApplicationCodeConfigurationDescriptionTypeDef = TypedDict(
@@ -606,7 +725,7 @@ CodeContentTypeDef = TypedDict(
     "CodeContentTypeDef",
     {
         "TextContent": str,
-        "ZipFileContent": Union[bytes, IO[bytes]],
+        "ZipFileContent": Union[bytes, IO[bytes], StreamingBody],
         "S3ContentLocation": "S3ContentLocationTypeDef",
     },
     total=False,
@@ -616,24 +735,83 @@ CodeContentUpdateTypeDef = TypedDict(
     "CodeContentUpdateTypeDef",
     {
         "TextContentUpdate": str,
-        "ZipFileContentUpdate": Union[bytes, IO[bytes]],
+        "ZipFileContentUpdate": Union[bytes, IO[bytes], StreamingBody],
         "S3ContentLocationUpdate": "S3ContentLocationUpdateTypeDef",
     },
     total=False,
 )
 
+_RequiredCreateApplicationPresignedUrlRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationPresignedUrlRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "UrlType": UrlTypeType,
+    },
+)
+_OptionalCreateApplicationPresignedUrlRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationPresignedUrlRequestRequestTypeDef",
+    {
+        "SessionExpirationDurationInSeconds": int,
+    },
+    total=False,
+)
+
+
+class CreateApplicationPresignedUrlRequestRequestTypeDef(
+    _RequiredCreateApplicationPresignedUrlRequestRequestTypeDef,
+    _OptionalCreateApplicationPresignedUrlRequestRequestTypeDef,
+):
+    pass
+
+
 CreateApplicationPresignedUrlResponseTypeDef = TypedDict(
     "CreateApplicationPresignedUrlResponseTypeDef",
     {
         "AuthorizedUrl": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "RuntimeEnvironment": RuntimeEnvironmentType,
+        "ServiceExecutionRole": str,
+    },
+)
+_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationDescription": str,
+        "ApplicationConfiguration": "ApplicationConfigurationTypeDef",
+        "CloudWatchLoggingOptions": List["CloudWatchLoggingOptionTypeDef"],
+        "Tags": List["TagTypeDef"],
+        "ApplicationMode": ApplicationModeType,
     },
     total=False,
 )
 
+
+class CreateApplicationRequestRequestTypeDef(
+    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
+):
+    pass
+
+
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateApplicationSnapshotRequestRequestTypeDef = TypedDict(
+    "CreateApplicationSnapshotRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "SnapshotName": str,
     },
 )
 
@@ -669,14 +847,47 @@ class CustomArtifactConfigurationTypeDef(
     pass
 
 
+_RequiredDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CloudWatchLoggingOptionId": str,
+    },
+)
+_OptionalDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    {
+        "CurrentApplicationVersionId": int,
+        "ConditionalToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef(
+    _RequiredDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef,
+    _OptionalDeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef,
+):
+    pass
+
+
 DeleteApplicationCloudWatchLoggingOptionResponseTypeDef = TypedDict(
     "DeleteApplicationCloudWatchLoggingOptionResponseTypeDef",
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
         "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "InputId": str,
     },
-    total=False,
 )
 
 DeleteApplicationInputProcessingConfigurationResponseTypeDef = TypedDict(
@@ -684,8 +895,17 @@ DeleteApplicationInputProcessingConfigurationResponseTypeDef = TypedDict(
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteApplicationOutputRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationOutputRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "OutputId": str,
     },
-    total=False,
 )
 
 DeleteApplicationOutputResponseTypeDef = TypedDict(
@@ -693,8 +913,17 @@ DeleteApplicationOutputResponseTypeDef = TypedDict(
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationReferenceDataSourceRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ReferenceId": str,
     },
-    total=False,
 )
 
 DeleteApplicationReferenceDataSourceResponseTypeDef = TypedDict(
@@ -702,17 +931,58 @@ DeleteApplicationReferenceDataSourceResponseTypeDef = TypedDict(
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteApplicationRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CreateTimestamp": Union[datetime, str],
+    },
+)
+
+DeleteApplicationSnapshotRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationSnapshotRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "SnapshotName": str,
+        "SnapshotCreationTimestamp": Union[datetime, str],
+    },
+)
+
+_RequiredDeleteApplicationVpcConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteApplicationVpcConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "VpcConfigurationId": str,
+    },
+)
+_OptionalDeleteApplicationVpcConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteApplicationVpcConfigurationRequestRequestTypeDef",
+    {
+        "CurrentApplicationVersionId": int,
+        "ConditionalToken": str,
     },
     total=False,
 )
 
+
+class DeleteApplicationVpcConfigurationRequestRequestTypeDef(
+    _RequiredDeleteApplicationVpcConfigurationRequestRequestTypeDef,
+    _OptionalDeleteApplicationVpcConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 DeleteApplicationVpcConfigurationResponseTypeDef = TypedDict(
     "DeleteApplicationVpcConfigurationResponseTypeDef",
     {
         "ApplicationARN": str,
         "ApplicationVersionId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DeployAsApplicationConfigurationDescriptionTypeDef = TypedDict(
@@ -736,10 +1006,41 @@ DeployAsApplicationConfigurationUpdateTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalDescribeApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeApplicationRequestRequestTypeDef",
+    {
+        "IncludeAdditionalDetails": bool,
+    },
+    total=False,
+)
+
+
+class DescribeApplicationRequestRequestTypeDef(
+    _RequiredDescribeApplicationRequestRequestTypeDef,
+    _OptionalDescribeApplicationRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeApplicationResponseTypeDef = TypedDict(
     "DescribeApplicationResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeApplicationSnapshotRequestRequestTypeDef = TypedDict(
+    "DescribeApplicationSnapshotRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "SnapshotName": str,
     },
 )
 
@@ -747,6 +1048,15 @@ DescribeApplicationSnapshotResponseTypeDef = TypedDict(
     "DescribeApplicationSnapshotResponseTypeDef",
     {
         "SnapshotDetails": "SnapshotDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeApplicationVersionRequestRequestTypeDef = TypedDict(
+    "DescribeApplicationVersionRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "ApplicationVersionId": int,
     },
 )
 
@@ -754,8 +1064,8 @@ DescribeApplicationVersionResponseTypeDef = TypedDict(
     "DescribeApplicationVersionResponseTypeDef",
     {
         "ApplicationVersionDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DestinationSchemaTypeDef = TypedDict(
@@ -765,6 +1075,31 @@ DestinationSchemaTypeDef = TypedDict(
     },
 )
 
+_RequiredDiscoverInputSchemaRequestRequestTypeDef = TypedDict(
+    "_RequiredDiscoverInputSchemaRequestRequestTypeDef",
+    {
+        "ServiceExecutionRole": str,
+    },
+)
+_OptionalDiscoverInputSchemaRequestRequestTypeDef = TypedDict(
+    "_OptionalDiscoverInputSchemaRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "S3Configuration": "S3ConfigurationTypeDef",
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class DiscoverInputSchemaRequestRequestTypeDef(
+    _RequiredDiscoverInputSchemaRequestRequestTypeDef,
+    _OptionalDiscoverInputSchemaRequestRequestTypeDef,
+):
+    pass
+
+
 DiscoverInputSchemaResponseTypeDef = TypedDict(
     "DiscoverInputSchemaResponseTypeDef",
     {
@@ -772,8 +1107,8 @@ DiscoverInputSchemaResponseTypeDef = TypedDict(
         "ParsedInputRecords": List[List[str]],
         "ProcessedInputRecords": List[str],
         "RawInputRecords": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EnvironmentPropertiesTypeDef = TypedDict(
@@ -1080,7 +1415,6 @@ KinesisFirehoseOutputTypeDef = TypedDict(
     "KinesisFirehoseOutputTypeDef",
     {
         "ResourceARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -1151,7 +1485,6 @@ KinesisStreamsOutputTypeDef = TypedDict(
     "KinesisStreamsOutputTypeDef",
     {
         "ResourceARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -1187,7 +1520,6 @@ LambdaOutputTypeDef = TypedDict(
     "LambdaOutputTypeDef",
     {
         "ResourceARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -1198,51 +1530,101 @@ LambdaOutputUpdateTypeDef = TypedDict(
     },
 )
 
+_RequiredListApplicationSnapshotsRequestRequestTypeDef = TypedDict(
+    "_RequiredListApplicationSnapshotsRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalListApplicationSnapshotsRequestRequestTypeDef = TypedDict(
+    "_OptionalListApplicationSnapshotsRequestRequestTypeDef",
+    {
+        "Limit": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListApplicationSnapshotsRequestRequestTypeDef(
+    _RequiredListApplicationSnapshotsRequestRequestTypeDef,
+    _OptionalListApplicationSnapshotsRequestRequestTypeDef,
+):
+    pass
+
+
 ListApplicationSnapshotsResponseTypeDef = TypedDict(
     "ListApplicationSnapshotsResponseTypeDef",
     {
         "SnapshotSummaries": List["SnapshotDetailsTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListApplicationVersionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListApplicationVersionsRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalListApplicationVersionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListApplicationVersionsRequestRequestTypeDef",
+    {
+        "Limit": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class ListApplicationVersionsRequestRequestTypeDef(
+    _RequiredListApplicationVersionsRequestRequestTypeDef,
+    _OptionalListApplicationVersionsRequestRequestTypeDef,
+):
+    pass
+
+
 ListApplicationVersionsResponseTypeDef = TypedDict(
     "ListApplicationVersionsResponseTypeDef",
     {
         "ApplicationVersionSummaries": List["ApplicationVersionSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredListApplicationsResponseTypeDef = TypedDict(
-    "_RequiredListApplicationsResponseTypeDef",
-    {
-        "ApplicationSummaries": List["ApplicationSummaryTypeDef"],
-    },
-)
-_OptionalListApplicationsResponseTypeDef = TypedDict(
-    "_OptionalListApplicationsResponseTypeDef",
+ListApplicationsRequestRequestTypeDef = TypedDict(
+    "ListApplicationsRequestRequestTypeDef",
     {
+        "Limit": int,
         "NextToken": str,
     },
     total=False,
 )
 
+ListApplicationsResponseTypeDef = TypedDict(
+    "ListApplicationsResponseTypeDef",
+    {
+        "ApplicationSummaries": List["ApplicationSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
-class ListApplicationsResponseTypeDef(
-    _RequiredListApplicationsResponseTypeDef, _OptionalListApplicationsResponseTypeDef
-):
-    pass
-
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MappingParametersTypeDef = TypedDict(
@@ -1318,18 +1700,28 @@ OutputDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-OutputTypeDef = TypedDict(
-    "OutputTypeDef",
+_RequiredOutputTypeDef = TypedDict(
+    "_RequiredOutputTypeDef",
     {
         "Name": str,
+        "DestinationSchema": "DestinationSchemaTypeDef",
+    },
+)
+_OptionalOutputTypeDef = TypedDict(
+    "_OptionalOutputTypeDef",
+    {
         "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
         "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
         "LambdaOutput": "LambdaOutputTypeDef",
-        "DestinationSchema": "DestinationSchemaTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
+
+class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
+    pass
+
+
 _RequiredOutputUpdateTypeDef = TypedDict(
     "_RequiredOutputUpdateTypeDef",
     {
@@ -1535,10 +1927,19 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RollbackApplicationRequestRequestTypeDef = TypedDict(
+    "RollbackApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+    },
+)
+
 RollbackApplicationResponseTypeDef = TypedDict(
     "RollbackApplicationResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -1817,6 +2218,56 @@ SqlRunConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredStartApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredStartApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalStartApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalStartApplicationRequestRequestTypeDef",
+    {
+        "RunConfiguration": "RunConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class StartApplicationRequestRequestTypeDef(
+    _RequiredStartApplicationRequestRequestTypeDef, _OptionalStartApplicationRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredStopApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredStopApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalStopApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalStopApplicationRequestRequestTypeDef",
+    {
+        "Force": bool,
+    },
+    total=False,
+)
+
+
+class StopApplicationRequestRequestTypeDef(
+    _RequiredStopApplicationRequestRequestTypeDef, _OptionalStopApplicationRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 _RequiredTagTypeDef = TypedDict(
     "_RequiredTagTypeDef",
     {
@@ -1836,19 +2287,62 @@ class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateApplicationMaintenanceConfigurationRequestRequestTypeDef = TypedDict(
+    "UpdateApplicationMaintenanceConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "ApplicationMaintenanceConfigurationUpdate": "ApplicationMaintenanceConfigurationUpdateTypeDef",
+    },
+)
+
 UpdateApplicationMaintenanceConfigurationResponseTypeDef = TypedDict(
     "UpdateApplicationMaintenanceConfigurationResponseTypeDef",
     {
         "ApplicationARN": str,
         "ApplicationMaintenanceConfigurationDescription": "ApplicationMaintenanceConfigurationDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalUpdateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateApplicationRequestRequestTypeDef",
+    {
+        "CurrentApplicationVersionId": int,
+        "ApplicationConfigurationUpdate": "ApplicationConfigurationUpdateTypeDef",
+        "ServiceExecutionRoleUpdate": str,
+        "RunConfigurationUpdate": "RunConfigurationUpdateTypeDef",
+        "CloudWatchLoggingOptionUpdates": List["CloudWatchLoggingOptionUpdateTypeDef"],
+        "ConditionalToken": str,
     },
     total=False,
 )
 
+
+class UpdateApplicationRequestRequestTypeDef(
+    _RequiredUpdateApplicationRequestRequestTypeDef, _OptionalUpdateApplicationRequestRequestTypeDef
+):
+    pass
+
+
 UpdateApplicationResponseTypeDef = TypedDict(
     "UpdateApplicationResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
